]> git.donarmstrong.com Git - mothur.git/blobdiff - geom.h
more calculator edits and added coverage and whittaker
[mothur.git] / geom.h
diff --git a/geom.h b/geom.h
index 56bc112d938faadc7efb2fe3e9faca12ca15ac79..f88cb4acb33d2cf4027062f309329f3bc9f9aaf6 100644 (file)
--- a/geom.h
+++ b/geom.h
@@ -6,12 +6,12 @@
  *  Mothur
  *
  *  Created by Thomas Ryabin on 2/23/09.
- *  Copyright 2009 __MyCompanyName__. All rights reserved.
+ *  Copyright 2009 Schloss Lab UMASS Amherst. All rights reserved.
  *
  */
 #include "calculator.h"
 
/* This class implements the LogSD estimator on single group. 
 It is a child of the calculator class. */
 
 /***********************************************************************/
@@ -19,7 +19,7 @@ It is a child of the calculator class. */
 class Geom : public Calculator  {
        
 public:
-       Geom() : Calculator("geom", 3) {};
+       Geom() : Calculator("geometric", 3) {};
        EstOutput getValues(SAbundVector*);
        EstOutput getValues(SharedRAbundVector*, SharedRAbundVector*) {return data;};
@@ -6,12 +6,12 @@
 #include "calculator.h"
 
-/* This class implements the LogSD estimator on single group. 
+/* This class implements the geometric estimator on single group. 
 It is a child of the calculator class. */
 